@@ -8,6 +8,7 @@ with 'Catalyst::Component::InstancePerContext';
 
 has user_id => (is=>'rw', clearer=>1, predicate=>1);
 has todo_query => (is=>'rw', clearer=>1, predicate=>1);
+has contacts_query => (is=>'rw', clearer=>1, predicate=>1);
 
 sub build_per_context_instance($self, $c) {
   return bless $c->session, ref($self);
@@ -16,7 +17,7 @@ sub build_per_context_instance($self, $c) {
 sub logout($self) {
   $self->clear_user_id;
   $self->clear_todo_query;
+  $self->clear_contacts_query
 }
 
 1;
-
