@@ -17,4 +17,9 @@ sub debug {
   return $self;
 }
 
+sub debug_off {
+  my ($self) = @_;
+  $self->result_source->schema->debug_off;
+  return $self;
+}
 1;
